

#include "FreeRTOS.h"
#include "task.h"



#include "LPC17xx.h"
#include "init.h"
#include "led.h"

#include "micro.h"
#include "ports.h"


/* Task priorities. */
#define mainLED_TASK_PRIORITY       ((tskIDLE_PRIORITY + 1) | portPRIVILEGE_BIT )
#define mainXILINX_TASK_PRIORITY    ((tskIDLE_PRIORITY + 2) | portPRIVILEGE_BIT )



unsigned char *xsvf_data;
extern unsigned char *xsvf_file;


void XilinxTask (void *pvParameters);
void XilinxTask (void *pvParameters)
{
    (void) pvParameters;
    int errorcode;


    /* LED: langsam bltzen */
    led_setMode(LED_MODE_FLASH_SLOW);

    LPC_GPIO0->FIODIR |= (1 << 9);
    LPC_GPIO2->FIODIR |= (1 << 0) | (1 << 1);
    LPC_GPIO2->FIODIR &= ~(1 << 2);

    /* Initialize the I/O.  SetPort initializes I/O on first call */
    setPort(TMS, 1);

    /* Set start pointer */
    xsvf_data = (unsigned char *)&xsvf_file;

    /* Execute the XSVF in the file */
    errorcode = xsvfExecute();

    if (errorcode == 0) {
        /* Alles ok: Langsam blinken */
        led_setMode(LED_MODE_BLINK_SLOW);
    }
    else {
        /* Leider ein Fehler...  Schnell blitzen */
        led_setMode(LED_MODE_FLASH_FAST);
    }

    while (1) {
        vTaskDelay(100);
    }
}



/*-----------------------------------------------------------*/



int main (void)
{
    /* Setup PLL */
    cpuInit();
    led_initModule();

    /* Für Diagnosezwecke: LED ausschalten. */
    LPC_GPIO1->FIOSET = (1 << 18);


    /* LED blinker */
    xTaskCreate(led_task, (signed char *)"LED", configMINIMAL_STACK_SIZE, (void *)NULL, mainLED_TASK_PRIORITY, NULL);

    /* Programmer */
    xTaskCreate(XilinxTask, (signed char *)"Xilinx", 1024, (void *)NULL, mainXILINX_TASK_PRIORITY, NULL);

    /* Start the scheduler. */
    vTaskStartScheduler();

    for (;;)
        ;
}



